Epoch: 1
Group: Development/Databases
# BEGIN SourceDeps(oneline):
BuildRequires: /usr/bin/jikes java-devel-default
# END SourceDeps(oneline)
# see https://bugzilla.altlinux.org/show_bug.cgi?id=10382
%define _localstatedir %{_var}
Name:           fastbit
Version:        2.0.3
Release:        alt2_29
Summary:        An Efficient Compressed Bitmap Index Technology
License:        BSD
URL:            https://sdm.lbl.gov/fastbit/
Source0:        https://code.lbl.gov/frs/download.php/file/426/%{name}-%{version}.tar.gz

# Code patch to fix format truncation issue, sent to upstream ML
Patch0:         fastbit_format_truncation.patch

# Code patch to fix FSF address in fbmerge.cpp, sent to upstream ML
Patch1:         fastbit_fsf_address.patch

# Code patch to remove indentation warnings, sent to upstream ML
Patch2:         fastbit_indentation.patch

# Code patch to remove unused variable warnings, sent to upstream ML
Patch3:         fastbit_unused_variable.patch

# Build system patch to ensure linkage to pthread
Patch10:        fastbit_pthread_linkage.patch

# Build system patch for tests to use compiled binaries, not libtool wrappers
Patch11:        fastbit_tests_use_binaries.patch

Patch30:        %{name}-gcc11.patch

BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  perl-devel
Source44: import.info

%description
FastBit is an open-source data processing library following the spirit of NoSQL
movement. It offers a set of searching functions supported by compressed bitmap
indexes. It treats user data in the column-oriented manner similar to
well-known database management systems such as Sybase IQ, MonetDB, and Vertica.
It is designed to accelerate user's data selection tasks without imposing undue
requirements.

%package devel
Group: Development/Databases
Summary: FastBit development
Requires: %{name} = %{?epoch:%epoch:}%{version}-%{release}
%description devel
Development package for FastBit.  Includes headers, libraries and man pages for
using FastBit API.

%prep
%setup -q -n %{name}-%{version}
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch10 -p1
%patch11 -p1
%patch30 -p1


echo fixing permissions ...
find . -type f -perm /0111 \
    \( -name \*.cpp -or -name \*.h -or -name \*.yy -or -name \*.ll -or \
       -name \*.html -or -name README \) -print -exec chmod 0644 {} \;

%build
aclocal -I tests/m4
autoconf
automake --copy --no-force
%configure \
    --disable-static \
    --enable-contrib \
    --with-quiet-nan
# patch libtool to remove rpaths
sed -i 's|^hardcode_into_libs=.*|hardcode_into_libs=no|g' libtool
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool
%make_build

%check
# The test binaries need LD_LIBRARY_PATH to find the compiled fastbit library
# in the build tree.
%make_build LD_LIBRARY_PATH="%{buildroot}%{_libdir};%{_libdir}" check

%install
%makeinstall_std

# remove libtool archives
find %{buildroot} -name \*.la | xargs rm -f




%files
%doc NEWS README
%doc --no-dereference COPYING
%{_docdir}/%{name}/*.html
%{_bindir}/ardea
%{_bindir}/fbmerge
%{_bindir}/ibis
%{_bindir}/rara
%{_bindir}/tcapi
%{_bindir}/thula
%{_bindir}/tiapi
%{_libdir}/libfastbit.so.*

%files devel
%dir %{_prefix}/include/%{name}
%{_prefix}/include/%{name}/*.h
%{_prefix}/include/%{name}/*.hh
%{_bindir}/fastbit-config
%{_libdir}/libfastbit.so

%changelog
* Sat Mar 23 2024 Igor Vlasenko <viy@altlinux.org> 1:2.0.3-alt2_29
- update to new release by fcimport

* Thu Aug 31 2023 Igor Vlasenko <viy@altlinux.org> 1:2.0.3-alt2_27
- update to new release by fcimport

* Wed Feb 22 2023 Igor Vlasenko <viy@altlinux.org> 1:2.0.3-alt2_26
- update to new release by fcimport

* Sun Aug 07 2022 Igor Vlasenko <viy@altlinux.org> 1:2.0.3-alt2_25
- update to new release by fcimport

* Thu May 05 2022 Igor Vlasenko <viy@altlinux.org> 1:2.0.3-alt2_24
- update to new release by fcimport

* Sat Feb 05 2022 Igor Vlasenko <viy@altlinux.org> 1:2.0.3-alt2_23
- update to new release by fcimport

* Mon Aug 02 2021 Igor Vlasenko <viy@altlinux.org> 1:2.0.3-alt2_22
- update to new release by fcimport

* Thu Jul 08 2021 Igor Vlasenko <viy@altlinux.org> 1:2.0.3-alt2_21
- update to new release by fcimport

* Wed Mar 17 2021 Igor Vlasenko <viy@altlinux.org> 1:2.0.3-alt2_20
- update to new release by fcimport

* Wed Jan 27 2021 Igor Vlasenko <viy@altlinux.ru> 1:2.0.3-alt2_19
- update to new release by fcimport

* Fri Dec 25 2020 Igor Vlasenko <viy@altlinux.ru> 1:2.0.3-alt1_19
- update to new release by fcimport

* Wed Sep 02 2020 Igor Vlasenko <viy@altlinux.ru> 1:2.0.3-alt1_18
- update to new release by fcimport

* Thu Feb 27 2020 Igor Vlasenko <viy@altlinux.ru> 1:2.0.3-alt1_16
- update to new release by fcimport

* Sat Sep 28 2019 Igor Vlasenko <viy@altlinux.ru> 1:2.0.3-alt1_14
- update to new release by fcimport

* Fri Mar 01 2019 Igor Vlasenko <viy@altlinux.ru> 1:2.0.3-alt1_9
- update to new release by fcimport

* Wed Aug 01 2018 Igor Vlasenko <viy@altlinux.ru> 1:2.0.3-alt1_8
- update to new release by fcimport

* Fri Jun 08 2018 Igor Vlasenko <viy@altlinux.ru> 1:2.0.3-alt1_7
- update to new release by fcimport

* Tue Mar 13 2018 Igor Vlasenko <viy@altlinux.ru> 1:2.0.3-alt1_6
- update to new release by fcimport

* Thu Mar 08 2018 Igor Vlasenko <viy@altlinux.ru> 1:2.0.3-alt1_5
- update to new release by fcimport

* Mon Feb 05 2018 Igor Vlasenko <viy@altlinux.ru> 1:2.0.3-alt1_3
- update to new release by fcimport

* Wed Nov 15 2017 Igor Vlasenko <viy@altlinux.ru> 1:2.0.3-alt1_1
- moved to autoimports

* Sat Jan 23 2016 Igor Vlasenko <viy@altlinux.ru> 1:2.0.1.9-alt2.svn20150305
- NMU: cleaned up dependencies for java

* Fri Mar 06 2015 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 1:2.0.1.9-alt1.svn20150305
- Version 2.0.1.9

* Thu May 29 2014 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 1:1.4.0-alt1.pre3.svn20140630
- Version 1.4.0pre3

* Thu May 29 2014 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> ibis1.3.9.5-alt1.svn20140516
- Version ibis1.3.9.5

* Wed Nov 13 2013 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> ibis1.3.8.2-alt1.svn20131031
- Version ibis1.3.8.2

* Thu Jun 20 2013 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> ibis1.3.7-alt1.svn20130615
- Version ibis1.3.7

* Mon Feb 04 2013 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> ibis1.3.5.1-alt1.svn20130111
- Version ibis1.3.5.1

* Sun Jun 03 2012 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> ibis1.3.0.3-alt1.svn20120601
- Version ibis1.3.0.3

* Fri Dec 16 2011 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> ibis1.2.6.1-alt1.svn20111215
- Version ibis1.2.6.1

* Sat Sep 03 2011 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> ibis1.2.4.10-alt1.svn20110829
- Version ibis1.2.4.10

* Thu May 12 2011 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> ibis1.2.3.2-alt1.svn20110508
- Version ibis1.2.3.2

* Wed Mar 16 2011 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> ibis1.2.0.2-alt1.svn20100924.5
- Added -g into compiler flags

* Thu Feb 10 2011 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> ibis1.2.0.2-alt1.svn20100924.4
- Rebuilt for debuginfo

* Thu Oct 28 2010 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> ibis1.2.0.2-alt1.svn20100924.3
- Rebuilt for soname set-versions

* Mon Oct 11 2010 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> ibis1.2.0.2-alt1.svn20100924.2
- Fixed underlinking of libraries

* Thu Sep 30 2010 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> ibis1.2.0.2-alt1.svn20100924.1
- Added explicit conflict between %name-examples and ibutils
- Avoid conflicts with libCoinCsdp-devel and libprimme-devel

* Wed Sep 29 2010 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> ibis1.2.0.2-alt1.svn20100924
- Initial build for Sisyphus

